import { describe, it, expect } from "vitest";
import {
  example,
  BOILERPLATE_OPTIONS,
  createDetails,
} from "../src/constants.js";

describe("constants", () => {
  it("example should be generated and include no build or connector code", () => {
    const result = example({ boilerplate: [] });

    expect(result).toContain(
      'import { NetlifyIntegration } from "@netlify/sdk";',
    );
    expect(result).toContain("const integration = new NetlifyIntegration();");
    expect(result).toContain("export { integration };");
    expect(result).not.toContain("addBuildEventHandler");
    expect(result).not.toContain("addConnector");
  });

  it("example should be generated and include build code", () => {
    const result = example({ boilerplate: [BOILERPLATE_OPTIONS.build] });

    expect(result).toContain(
      'import { NetlifyIntegration } from "@netlify/sdk";',
    );
    expect(result).toContain("const integration = new NetlifyIntegration();");
    expect(result).toContain("export { integration };");
    expect(result).toContain("addBuildEventHandler");
    expect(result).not.toContain("addConnector");
  });

  it("example should be generated and include connector code", () => {
    const result = example({ boilerplate: [BOILERPLATE_OPTIONS.connector] });

    expect(result).toContain(
      'import { NetlifyIntegration } from "@netlify/sdk";',
    );
    expect(result).toContain("const integration = new NetlifyIntegration();");
    expect(result).toContain("export { integration };");
    expect(result).not.toContain("addBuildEventHandler");
    expect(result).toContain("addConnector");
  });

  it("example should be generated and include build and connector code", () => {
    const result = example({
      boilerplate: [BOILERPLATE_OPTIONS.build, BOILERPLATE_OPTIONS.connector],
    });

    expect(result).toContain(
      'import { NetlifyIntegration } from "@netlify/sdk";',
    );
    expect(result).toContain("const integration = new NetlifyIntegration();");
    expect(result).toContain("export { integration };");
    expect(result).toContain("addBuildEventHandler");
    expect(result).toContain("addConnector");
  });

  it("details file should be generated", () => {
    const integrationName = "Test Integration";
    const result = createDetails(integrationName);
    expect(result).toContain(
      `View and install the ${integrationName} integration.`,
    );
  });
});
